# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/mdb/postgresql/v1/perf_diag.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n.yandex/cloud/mdb/postgresql/v1/perf_diag.proto\x12\x1eyandex.cloud.mdb.postgresql.v1\x1a\x1fgoogle/protobuf/timestamp.proto\"\xd1\x04\n\x0cSessionState\x12(\n\x04time\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04host\x18\x02 \x01(\t\x12\x0b\n\x03pid\x18\x03 \x01(\x03\x12\x10\n\x08\x64\x61tabase\x18\x04 \x01(\t\x12\x0c\n\x04user\x18\x05 \x01(\t\x12\x18\n\x10\x61pplication_name\x18\x06 \x01(\t\x12\x31\n\rbackend_start\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nxact_start\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12/\n\x0bquery_start\x18\t \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x30\n\x0cstate_change\x18\n \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x17\n\x0fwait_event_type\x18\x0b \x01(\t\x12\x12\n\nwait_event\x18\x0c \x01(\t\x12\r\n\x05state\x18\r \x01(\t\x12\r\n\x05query\x18\x0e \x01(\t\x12\x14\n\x0c\x62\x61\x63kend_type\x18\x0f \x01(\t\x12\x13\n\x0b\x63lient_addr\x18\x10 \x01(\t\x12\x17\n\x0f\x63lient_hostname\x18\x11 \x01(\t\x12\x13\n\x0b\x63lient_port\x18\x12 \x01(\x03\x12\x13\n\x0b\x62\x61\x63kend_xid\x18\x13 \x01(\x03\x12\x14\n\x0c\x62\x61\x63kend_xmin\x18\x14 \x01(\x03\x12\x15\n\rblocking_pids\x18\x16 \x01(\t\x12\x10\n\x08query_id\x18\x17 \x01(\tJ\x04\x08\x15\x10\x16\"u\n\nPrimaryKey\x12\x0c\n\x04host\x18\x01 \x01(\t\x12\x0c\n\x04user\x18\x02 \x01(\t\x12\x10\n\x08\x64\x61tabase\x18\x04 \x01(\t\x12\x10\n\x08toplevel\x18\x05 \x01(\x08\x12\x10\n\x08query_id\x18\x06 \x01(\t\x12\x0f\n\x07plan_id\x18\x07 \x01(\tJ\x04\x08\x03\x10\x04\"\x9c\t\n\nQueryStats\x12(\n\x04time\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\r\n\x05query\x18\x02 \x01(\t\x12\x17\n\x0fnormalized_plan\x18\x03 \x01(\t\x12\x14\n\x0c\x65xample_plan\x18\x04 \x01(\t\x12\r\n\x05plans\x18\x05 \x01(\x03\x12\x17\n\x0ftotal_plan_time\x18\x06 \x01(\x01\x12\x15\n\rmin_plan_time\x18\x07 \x01(\x01\x12\x15\n\rmax_plan_time\x18\x08 \x01(\x01\x12\x16\n\x0emean_plan_time\x18\t \x01(\x01\x12\x18\n\x10stddev_plan_time\x18\n \x01(\x01\x12\r\n\x05\x63\x61lls\x18\x0b \x01(\x03\x12\x12\n\ntotal_time\x18\x0c \x01(\x01\x12\x10\n\x08min_time\x18\r \x01(\x01\x12\x10\n\x08max_time\x18\x0e \x01(\x01\x12\x11\n\tmean_time\x18\x0f \x01(\x01\x12\x13\n\x0bstddev_time\x18\x10 \x01(\x01\x12\x0c\n\x04rows\x18\x11 \x01(\x03\x12\x17\n\x0fshared_blks_hit\x18\x12 \x01(\x03\x12\x18\n\x10shared_blks_read\x18\x13 \x01(\x03\x12\x1b\n\x13shared_blks_dirtied\x18\x14 \x01(\x03\x12\x1b\n\x13shared_blks_written\x18\x15 \x01(\x03\x12\x16\n\x0elocal_blks_hit\x18\x16 \x01(\x03\x12\x17\n\x0flocal_blks_read\x18\x17 \x01(\x03\x12\x1a\n\x12local_blks_dirtied\x18\x18 \x01(\x03\x12\x1a\n\x12local_blks_written\x18\x19 \x01(\x03\x12\x16\n\x0etemp_blks_read\x18\x1a \x01(\x03\x12\x19\n\x11temp_blks_written\x18\x1b \x01(\x03\x12\x15\n\rblk_read_time\x18\x1c \x01(\x01\x12\x16\n\x0e\x62lk_write_time\x18\x1d \x01(\x01\x12\x1a\n\x12temp_blk_read_time\x18\x1e \x01(\x01\x12\x1b\n\x13temp_blk_write_time\x18\x1f \x01(\x01\x12\x13\n\x0bwal_records\x18  \x01(\x03\x12\x0f\n\x07wal_fpi\x18! \x01(\x03\x12\x11\n\twal_bytes\x18\" \x01(\x03\x12\x15\n\rjit_functions\x18# \x01(\x03\x12\x1b\n\x13jit_generation_time\x18$ \x01(\x01\x12\x1a\n\x12jit_inlining_count\x18% \x01(\x03\x12\x19\n\x11jit_inlining_time\x18& \x01(\x01\x12\x1e\n\x16jit_optimization_count\x18\' \x01(\x03\x12\x1d\n\x15jit_optimization_time\x18( \x01(\x01\x12\x1a\n\x12jit_emission_count\x18) \x01(\x03\x12\x19\n\x11jit_emission_time\x18* \x01(\x01\x12\x14\n\x0cstartup_cost\x18+ \x01(\x03\x12\x12\n\ntotal_cost\x18, \x01(\x03\x12\x11\n\tplan_rows\x18- \x01(\x03\x12\x12\n\nplan_width\x18. \x01(\x03\x12\r\n\x05reads\x18/ \x01(\x03\x12\x0e\n\x06writes\x18\x30 \x01(\x03\x12\x11\n\tuser_time\x18\x31 \x01(\x01\x12\x13\n\x0bsystem_time\x18\x32 \x01(\x01\"\x84\x01\n\x0eQueryStatement\x12\x37\n\x03key\x18\x01 \x01(\x0b\x32*.yandex.cloud.mdb.postgresql.v1.PrimaryKey\x12\x39\n\x05stats\x18\x02 \x01(\x0b\x32*.yandex.cloud.mdb.postgresql.v1.QueryStatsBs\n\"yandex.cloud.api.mdb.postgresql.v1ZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/postgresql/v1;postgresqlb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.mdb.postgresql.v1.perf_diag_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\"yandex.cloud.api.mdb.postgresql.v1ZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/postgresql/v1;postgresql'
  _globals['_SESSIONSTATE']._serialized_start=116
  _globals['_SESSIONSTATE']._serialized_end=709
  _globals['_PRIMARYKEY']._serialized_start=711
  _globals['_PRIMARYKEY']._serialized_end=828
  _globals['_QUERYSTATS']._serialized_start=831
  _globals['_QUERYSTATS']._serialized_end=2011
  _globals['_QUERYSTATEMENT']._serialized_start=2014
  _globals['_QUERYSTATEMENT']._serialized_end=2146
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/loadtesting/agent/v1/test.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,yandex/cloud/loadtesting/agent/v1/test.proto\x12!yandex.cloud.loadtesting.agent.v1\x1a\x1fgoogle/protobuf/timestamp.proto\"\x88\x08\n\x04Test\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\tfolder_id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12\x43\n\x06labels\x18\x05 \x03(\x0b\x32\x33.yandex.cloud.loadtesting.agent.v1.Test.LabelsEntry\x12.\n\ncreated_at\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nstarted_at\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12/\n\x0b\x66inished_at\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nupdated_at\x18\t \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x44\n\tgenerator\x18\n \x01(\x0e\x32\x31.yandex.cloud.loadtesting.agent.v1.Test.Generator\x12\x19\n\x11\x61gent_instance_id\x18\x0b \x01(\t\x12\x16\n\x0etarget_address\x18\x0c \x01(\t\x12\x13\n\x0btarget_port\x18\r \x01(\x03\x12\x16\n\x0etarget_version\x18\x0e \x01(\t\x12\x0e\n\x06\x63onfig\x18\x0f \x01(\t\x12\x13\n\tammo_urls\x18\x10 \x01(\tH\x00\x12\x11\n\x07\x61mmo_id\x18\x11 \x01(\tH\x00\x12\r\n\x05\x63\x61ses\x18\x12 \x03(\t\x12>\n\x06status\x18\x13 \x01(\x0e\x32..yandex.cloud.loadtesting.agent.v1.Test.Status\x12\x0e\n\x06\x65rrors\x18\x14 \x03(\t\x12\x10\n\x08\x66\x61vorite\x18\x15 \x01(\x08\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xe3\x01\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\x0b\n\x07\x43REATED\x10\x01\x12\r\n\tINITIATED\x10\x02\x12\r\n\tPREPARING\x10\x03\x12\x0b\n\x07RUNNING\x10\x04\x12\r\n\tFINISHING\x10\x05\x12\x08\n\x04\x44ONE\x10\x06\x12\x13\n\x0fPOST_PROCESSING\x10\x07\x12\n\n\x06\x46\x41ILED\x10\x08\x12\x0c\n\x08STOPPING\x10\t\x12\x0b\n\x07STOPPED\x10\n\x12\x0f\n\x0b\x41UTOSTOPPED\x10\x0b\x12\x0b\n\x07WAITING\x10\x0c\x12\x0c\n\x08\x44\x45LETING\x10\r\x12\x08\n\x04LOST\x10\x0e\"L\n\tGenerator\x12\x19\n\x15GENERATOR_UNSPECIFIED\x10\x00\x12\x0b\n\x07PANDORA\x10\x01\x12\x0b\n\x07PHANTOM\x10\x02\x12\n\n\x06JMETER\x10\x03\x42\x06\n\x04\x61mmoBt\n%yandex.cloud.api.loadtesting.agent.v1ZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/loadtesting/agent/v1;agentb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.loadtesting.agent.v1.test_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n%yandex.cloud.api.loadtesting.agent.v1ZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/loadtesting/agent/v1;agent'
  _TEST_LABELSENTRY._options = None
  _TEST_LABELSENTRY._serialized_options = b'8\001'
  _globals['_TEST']._serialized_start=117
  _globals['_TEST']._serialized_end=1149
  _globals['_TEST_LABELSENTRY']._serialized_start=788
  _globals['_TEST_LABELSENTRY']._serialized_end=833
  _globals['_TEST_STATUS']._serialized_start=836
  _globals['_TEST_STATUS']._serialized_end=1063
  _globals['_TEST_GENERATOR']._serialized_start=1065
  _globals['_TEST_GENERATOR']._serialized_end=1141
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.wrappers_pb2
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class LagInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LAG_ID_FIELD_NUMBER: builtins.int
    PORT_NAMES_FIELD_NUMBER: builtins.int
    @property
    def lag_id(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """ID of LAG.
        Optional.
        If is not set scheduler selects it by himself.
        """

    @property
    def port_names(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """List of port names that the LAG is deployed on."""

    def __init__(
        self,
        *,
        lag_id: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        port_names: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["lag_id", b"lag_id"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["lag_id", b"lag_id", "port_names", b"port_names"]) -> None: ...

global___LagInfo = LagInfo



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/containerregistry/v1/scan_policy_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.containerregistry.v1 import scan_policy_pb2 as yandex_dot_cloud_dot_containerregistry_dot_v1_dot_scan__policy__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n;yandex/cloud/containerregistry/v1/scan_policy_service.proto\x12!yandex.cloud.containerregistry.v1\x1a yandex/cloud/api/operation.proto\x1a\x33yandex/cloud/containerregistry/v1/scan_policy.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\x1a google/protobuf/field_mask.proto\x1a\x1cgoogle/api/annotations.proto\"<\n\x14GetScanPolicyRequest\x12$\n\x0escan_policy_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"C\n\x1eGetScanPolicyByRegistryRequest\x12!\n\x0bregistry_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"\xca\x01\n\x17\x43reateScanPolicyRequest\x12!\n\x0bregistry_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12/\n\x04name\x18\x02 \x01(\tB!\xf2\xc7\x31\x1d|[a-z][-a-z0-9]{1,61}[a-z0-9]\x12\x1e\n\x0b\x64\x65scription\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12;\n\x05rules\x18\x04 \x01(\x0b\x32,.yandex.cloud.containerregistry.v1.ScanRules\"\xfe\x01\n\x17UpdateScanPolicyRequest\x12$\n\x0escan_policy_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12/\n\x04name\x18\x03 \x01(\tB!\xf2\xc7\x31\x1d|[a-z][-a-z0-9]{1,61}[a-z0-9]\x12\x1e\n\x0b\x64\x65scription\x18\x04 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12;\n\x05rules\x18\x05 \x01(\x0b\x32,.yandex.cloud.containerregistry.v1.ScanRules\"?\n\x17\x44\x65leteScanPolicyRequest\x12$\n\x0escan_policy_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"2\n\x18\x43reateScanPolicyMetadata\x12\x16\n\x0escan_policy_id\x18\x01 \x01(\t\"2\n\x18UpdateScanPolicyMetadata\x12\x16\n\x0escan_policy_id\x18\x01 \x01(\t\"2\n\x18\x44\x65leteScanPolicyMetadata\x12\x16\n\x0escan_policy_id\x18\x01 \x01(\t2\x81\x08\n\x11ScanPolicyService\x12\xab\x01\n\x03Get\x12\x37.yandex.cloud.containerregistry.v1.GetScanPolicyRequest\x1a-.yandex.cloud.containerregistry.v1.ScanPolicy\"<\x82\xd3\xe4\x93\x02\x36\x12\x34/container-registry/v1/scanPolicies/{scan_policy_id}\x12\xc7\x01\n\rGetByRegistry\x12\x41.yandex.cloud.containerregistry.v1.GetScanPolicyByRegistryRequest\x1a-.yandex.cloud.containerregistry.v1.ScanPolicy\"D\x82\xd3\xe4\x93\x02>\x12</container-registry/v1/scanPolicies/{registry_id}:byRegistry\x12\xc1\x01\n\x06\x43reate\x12:.yandex.cloud.containerregistry.v1.CreateScanPolicyRequest\x1a!.yandex.cloud.operation.Operation\"X\xb2\xd2*&\n\x18\x43reateScanPolicyMetadata\x12\nScanPolicy\x82\xd3\xe4\x93\x02(\"#/container-registry/v1/scanPolicies:\x01*\x12\xd2\x01\n\x06Update\x12:.yandex.cloud.containerregistry.v1.UpdateScanPolicyRequest\x1a!.yandex.cloud.operation.Operation\"i\xb2\xd2*&\n\x18UpdateScanPolicyMetadata\x12\nScanPolicy\x82\xd3\xe4\x93\x02\x39\x32\x34/container-registry/v1/scanPolicies/{scan_policy_id}:\x01*\x12\xda\x01\n\x06\x44\x65lete\x12:.yandex.cloud.containerregistry.v1.DeleteScanPolicyRequest\x1a!.yandex.cloud.operation.Operation\"q\xb2\xd2*1\n\x18\x44\x65leteScanPolicyMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02\x36*4/container-registry/v1/scanPolicies/{scan_policy_id}B\x80\x01\n%yandex.cloud.api.containerregistry.v1ZWgithub.com/yandex-cloud/go-genproto/yandex/cloud/containerregistry/v1;containerregistryb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.containerregistry.v1.scan_policy_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n%yandex.cloud.api.containerregistry.v1ZWgithub.com/yandex-cloud/go-genproto/yandex/cloud/containerregistry/v1;containerregistry'
  _GETSCANPOLICYREQUEST.fields_by_name['scan_policy_id']._options = None
  _GETSCANPOLICYREQUEST.fields_by_name['scan_policy_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _GETSCANPOLICYBYREGISTRYREQUEST.fields_by_name['registry_id']._options = None
  _GETSCANPOLICYBYREGISTRYREQUEST.fields_by_name['registry_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _CREATESCANPOLICYREQUEST.fields_by_name['registry_id']._options = None
  _CREATESCANPOLICYREQUEST.fields_by_name['registry_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _CREATESCANPOLICYREQUEST.fields_by_name['name']._options = None
  _CREATESCANPOLICYREQUEST.fields_by_name['name']._serialized_options = b'\362\3071\035|[a-z][-a-z0-9]{1,61}[a-z0-9]'
  _CREATESCANPOLICYREQUEST.fields_by_name['description']._options = None
  _CREATESCANPOLICYREQUEST.fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _UPDATESCANPOLICYREQUEST.fields_by_name['scan_policy_id']._options = None
  _UPDATESCANPOLICYREQUEST.fields_by_name['scan_policy_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _UPDATESCANPOLICYREQUEST.fields_by_name['name']._options = None
  _UPDATESCANPOLICYREQUEST.fields_by_name['name']._serialized_options = b'\362\3071\035|[a-z][-a-z0-9]{1,61}[a-z0-9]'
  _UPDATESCANPOLICYREQUEST.fields_by_name['description']._options = None
  _UPDATESCANPOLICYREQUEST.fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _DELETESCANPOLICYREQUEST.fields_by_name['scan_policy_id']._options = None
  _DELETESCANPOLICYREQUEST.fields_by_name['scan_policy_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _SCANPOLICYSERVICE.methods_by_name['Get']._options = None
  _SCANPOLICYSERVICE.methods_by_name['Get']._serialized_options = b'\202\323\344\223\0026\0224/container-registry/v1/scanPolicies/{scan_policy_id}'
  _SCANPOLICYSERVICE.methods_by_name['GetByRegistry']._options = None
  _SCANPOLICYSERVICE.methods_by_name['GetByRegistry']._serialized_options = b'\202\323\344\223\002>\022</container-registry/v1/scanPolicies/{registry_id}:byRegistry'
  _SCANPOLICYSERVICE.methods_by_name['Create']._options = None
  _SCANPOLICYSERVICE.methods_by_name['Create']._serialized_options = b'\262\322*&\n\030CreateScanPolicyMetadata\022\nScanPolicy\202\323\344\223\002(\"#/container-registry/v1/scanPolicies:\001*'
  _SCANPOLICYSERVICE.methods_by_name['Update']._options = None
  _SCANPOLICYSERVICE.methods_by_name['Update']._serialized_options = b'\262\322*&\n\030UpdateScanPolicyMetadata\022\nScanPolicy\202\323\344\223\002924/container-registry/v1/scanPolicies/{scan_policy_id}:\001*'
  _SCANPOLICYSERVICE.methods_by_name['Delete']._options = None
  _SCANPOLICYSERVICE.methods_by_name['Delete']._serialized_options = b'\262\322*1\n\030DeleteScanPolicyMetadata\022\025google.protobuf.Empty\202\323\344\223\0026*4/container-registry/v1/scanPolicies/{scan_policy_id}'
  _globals['_GETSCANPOLICYREQUEST']._serialized_start=320
  _globals['_GETSCANPOLICYREQUEST']._serialized_end=380
  _globals['_GETSCANPOLICYBYREGISTRYREQUEST']._serialized_start=382
  _globals['_GETSCANPOLICYBYREGISTRYREQUEST']._serialized_end=449
  _globals['_CREATESCANPOLICYREQUEST']._serialized_start=452
  _globals['_CREATESCANPOLICYREQUEST']._serialized_end=654
  _globals['_UPDATESCANPOLICYREQUEST']._serialized_start=657
  _globals['_UPDATESCANPOLICYREQUEST']._serialized_end=911
  _globals['_DELETESCANPOLICYREQUEST']._serialized_start=913
  _globals['_DELETESCANPOLICYREQUEST']._serialized_end=976
  _globals['_CREATESCANPOLICYMETADATA']._serialized_start=978
  _globals['_CREATESCANPOLICYMETADATA']._serialized_end=1028
  _globals['_UPDATESCANPOLICYMETADATA']._serialized_start=1030
  _globals['_UPDATESCANPOLICYMETADATA']._serialized_end=1080
  _globals['_DELETESCANPOLICYMETADATA']._serialized_start=1082
  _globals['_DELETESCANPOLICYMETADATA']._serialized_end=1132
  _globals['_SCANPOLICYSERVICE']._serialized_start=1135
  _globals['_SCANPOLICYSERVICE']._serialized_end=2160
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.operation.operation_pb2
import yandex.cloud.storage.v1.bucket_pb2
import yandex.cloud.storage.v1.bucket_service_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class BucketServiceStub:
    """A set of methods for managing buckets."""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    List: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.storage.v1.bucket_service_pb2.ListBucketsRequest,
        yandex.cloud.storage.v1.bucket_service_pb2.ListBucketsResponse,
    ]
    """Retrieves the list of buckets in the specified folder.

    The following fields will not be returned for buckets in the list: [Bucket.policy], [Bucket.acl], [Bucket.cors],
    [Bucket.website_settings], [Bucket.lifecycle_rules], [Bucket.tags].
    """

    Get: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.storage.v1.bucket_service_pb2.GetBucketRequest,
        yandex.cloud.storage.v1.bucket_pb2.Bucket,
    ]
    """Returns the specified bucket.

    To get the list of all available buckets, make a [List] request.
    """

    Create: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.storage.v1.bucket_service_pb2.CreateBucketRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates a bucket in the specified folder."""

    Update: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.storage.v1.bucket_service_pb2.UpdateBucketRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates the specified bucket.

    In most cases, `storage.editor` role (see [documentation](/docs/storage/security/#storage-editor)) should be enough
    to update a bucket, subject to its [policy](/docs/storage/concepts/policy).
    """

    Delete: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.storage.v1.bucket_service_pb2.DeleteBucketRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified bucket."""

    GetStats: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.storage.v1.bucket_service_pb2.GetBucketStatsRequest,
        yandex.cloud.storage.v1.bucket_pb2.BucketStats,
    ]
    """Returns the statistics for the specified bucket."""

    GetHTTPSConfig: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.storage.v1.bucket_service_pb2.GetBucketHTTPSConfigRequest,
        yandex.cloud.storage.v1.bucket_pb2.HTTPSConfig,
    ]
    """Returns the HTTPS configuration for the specified bucket."""

    SetHTTPSConfig: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.storage.v1.bucket_service_pb2.SetBucketHTTPSConfigRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates the HTTPS configuration for the specified bucket.

    The updated configuration could take up to 30 minutes to apply to the bucket.
    """

    DeleteHTTPSConfig: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.storage.v1.bucket_service_pb2.DeleteBucketHTTPSConfigRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the HTTPS configuration for the specified bucket."""

class BucketServiceAsyncStub:
    """A set of methods for managing buckets."""

    List: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.storage.v1.bucket_service_pb2.ListBucketsRequest,
        yandex.cloud.storage.v1.bucket_service_pb2.ListBucketsResponse,
    ]
    """Retrieves the list of buckets in the specified folder.

    The following fields will not be returned for buckets in the list: [Bucket.policy], [Bucket.acl], [Bucket.cors],
    [Bucket.website_settings], [Bucket.lifecycle_rules], [Bucket.tags].
    """

    Get: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.storage.v1.bucket_service_pb2.GetBucketRequest,
        yandex.cloud.storage.v1.bucket_pb2.Bucket,
    ]
    """Returns the specified bucket.

    To get the list of all available buckets, make a [List] request.
    """

    Create: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.storage.v1.bucket_service_pb2.CreateBucketRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates a bucket in the specified folder."""

    Update: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.storage.v1.bucket_service_pb2.UpdateBucketRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates the specified bucket.

    In most cases, `storage.editor` role (see [documentation](/docs/storage/security/#storage-editor)) should be enough
    to update a bucket, subject to its [policy](/docs/storage/concepts/policy).
    """

    Delete: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.storage.v1.bucket_service_pb2.DeleteBucketRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified bucket."""

    GetStats: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.storage.v1.bucket_service_pb2.GetBucketStatsRequest,
        yandex.cloud.storage.v1.bucket_pb2.BucketStats,
    ]
    """Returns the statistics for the specified bucket."""

    GetHTTPSConfig: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.storage.v1.bucket_service_pb2.GetBucketHTTPSConfigRequest,
        yandex.cloud.storage.v1.bucket_pb2.HTTPSConfig,
    ]
    """Returns the HTTPS configuration for the specified bucket."""

    SetHTTPSConfig: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.storage.v1.bucket_service_pb2.SetBucketHTTPSConfigRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates the HTTPS configuration for the specified bucket.

    The updated configuration could take up to 30 minutes to apply to the bucket.
    """

    DeleteHTTPSConfig: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.storage.v1.bucket_service_pb2.DeleteBucketHTTPSConfigRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the HTTPS configuration for the specified bucket."""

class BucketServiceServicer(metaclass=abc.ABCMeta):
    """A set of methods for managing buckets."""

    @abc.abstractmethod
    def List(
        self,
        request: yandex.cloud.storage.v1.bucket_service_pb2.ListBucketsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.storage.v1.bucket_service_pb2.ListBucketsResponse, collections.abc.Awaitable[yandex.cloud.storage.v1.bucket_service_pb2.ListBucketsResponse]]:
        """Retrieves the list of buckets in the specified folder.

        The following fields will not be returned for buckets in the list: [Bucket.policy], [Bucket.acl], [Bucket.cors],
        [Bucket.website_settings], [Bucket.lifecycle_rules], [Bucket.tags].
        """

    @abc.abstractmethod
    def Get(
        self,
        request: yandex.cloud.storage.v1.bucket_service_pb2.GetBucketRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.storage.v1.bucket_pb2.Bucket, collections.abc.Awaitable[yandex.cloud.storage.v1.bucket_pb2.Bucket]]:
        """Returns the specified bucket.

        To get the list of all available buckets, make a [List] request.
        """

    @abc.abstractmethod
    def Create(
        self,
        request: yandex.cloud.storage.v1.bucket_service_pb2.CreateBucketRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Creates a bucket in the specified folder."""

    @abc.abstractmethod
    def Update(
        self,
        request: yandex.cloud.storage.v1.bucket_service_pb2.UpdateBucketRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Updates the specified bucket.

        In most cases, `storage.editor` role (see [documentation](/docs/storage/security/#storage-editor)) should be enough
        to update a bucket, subject to its [policy](/docs/storage/concepts/policy).
        """

    @abc.abstractmethod
    def Delete(
        self,
        request: yandex.cloud.storage.v1.bucket_service_pb2.DeleteBucketRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Deletes the specified bucket."""

    @abc.abstractmethod
    def GetStats(
        self,
        request: yandex.cloud.storage.v1.bucket_service_pb2.GetBucketStatsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.storage.v1.bucket_pb2.BucketStats, collections.abc.Awaitable[yandex.cloud.storage.v1.bucket_pb2.BucketStats]]:
        """Returns the statistics for the specified bucket."""

    @abc.abstractmethod
    def GetHTTPSConfig(
        self,
        request: yandex.cloud.storage.v1.bucket_service_pb2.GetBucketHTTPSConfigRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.storage.v1.bucket_pb2.HTTPSConfig, collections.abc.Awaitable[yandex.cloud.storage.v1.bucket_pb2.HTTPSConfig]]:
        """Returns the HTTPS configuration for the specified bucket."""

    @abc.abstractmethod
    def SetHTTPSConfig(
        self,
        request: yandex.cloud.storage.v1.bucket_service_pb2.SetBucketHTTPSConfigRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Updates the HTTPS configuration for the specified bucket.

        The updated configuration could take up to 30 minutes to apply to the bucket.
        """

    @abc.abstractmethod
    def DeleteHTTPSConfig(
        self,
        request: yandex.cloud.storage.v1.bucket_service_pb2.DeleteBucketHTTPSConfigRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Deletes the HTTPS configuration for the specified bucket."""

def add_BucketServiceServicer_to_server(servicer: BucketServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/serverless/mdbproxy/v1/proxy_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.access import access_pb2 as yandex_dot_cloud_dot_access_dot_access__pb2
from yandex.cloud.serverless.mdbproxy.v1 import proxy_pb2 as yandex_dot_cloud_dot_serverless_dot_mdbproxy_dot_v1_dot_proxy__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n7yandex/cloud/serverless/mdbproxy/v1/proxy_service.proto\x12#yandex.cloud.serverless.mdbproxy.v1\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a yandex/cloud/api/operation.proto\x1a yandex/cloud/access/access.proto\x1a/yandex/cloud/serverless/mdbproxy/v1/proxy.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\"1\n\x0fGetProxyRequest\x12\x1e\n\x08proxy_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"\x8d\x01\n\x10ListProxyRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1a\n\x06\x66ilter\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1000\"t\n\x11ListProxyResponse\x12;\n\x07proxies\x18\x01 \x03(\x0b\x32*.yandex.cloud.serverless.mdbproxy.v1.Proxy\x12\"\n\x0fnext_page_token\x18\x02 \x01(\tB\t\x8a\xc8\x31\x05<=100\"\x8b\x03\n\x12\x43reateProxyRequest\x12\x17\n\tfolder_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12/\n\x04name\x18\x02 \x01(\tB!\xf2\xc7\x31\x1d|[a-z][-a-z0-9]{1,61}[a-z0-9]\x12\x1e\n\x0b\x64\x65scription\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x98\x01\n\x06labels\x18\x04 \x03(\x0b\x32\x43.yandex.cloud.serverless.mdbproxy.v1.CreateProxyRequest.LabelsEntryBC\xf2\xc7\x31\x0f[-_./\\@0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x1c\x12\x14[a-z][-_./\\@0-9a-z]*\x1a\x04\x31-63\x12\x41\n\x06target\x18\x05 \x01(\x0b\x32+.yandex.cloud.serverless.mdbproxy.v1.TargetB\x04\xe8\xc7\x31\x01\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"1\n\x13\x43reateProxyMetadata\x12\x1a\n\x08proxy_id\x18\x01 \x01(\tB\x08\x8a\xc8\x31\x04<=50\"\xb5\x03\n\x12UpdateProxyRequest\x12\x16\n\x08proxy_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12/\n\x04name\x18\x03 \x01(\tB!\xf2\xc7\x31\x1d|[a-z][-a-z0-9]{1,61}[a-z0-9]\x12\x1e\n\x0b\x64\x65scription\x18\x04 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x98\x01\n\x06labels\x18\x05 \x03(\x0b\x32\x43.yandex.cloud.serverless.mdbproxy.v1.UpdateProxyRequest.LabelsEntryBC\xf2\xc7\x31\x0f[-_./\\@0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x1c\x12\x14[a-z][-_./\\@0-9a-z]*\x1a\x04\x31-63\x12;\n\x06target\x18\x06 \x01(\x0b\x32+.yandex.cloud.serverless.mdbproxy.v1.Target\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"5\n\x13UpdateProxyMetadata\x12\x1e\n\x08proxy_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"4\n\x12\x44\x65leteProxyRequest\x12\x1e\n\x08proxy_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"5\n\x13\x44\x65leteProxyMetadata\x12\x1e\n\x08proxy_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"\x8e\x01\n\x1aListProxyOperationsRequest\x12\x16\n\x08proxy_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1a\n\x06\x66ilter\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1000\"m\n\x1bListProxyOperationsResponse\x12\x35\n\noperations\x18\x01 \x03(\x0b\x32!.yandex.cloud.operation.Operation\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t2\xac\r\n\x0cProxyService\x12\x90\x01\n\x03Get\x12\x34.yandex.cloud.serverless.mdbproxy.v1.GetProxyRequest\x1a*.yandex.cloud.serverless.mdbproxy.v1.Proxy\"\'\x82\xd3\xe4\x93\x02!\x12\x1f/mdbproxy/v1/proxies/{proxy_id}\x12\x93\x01\n\x04List\x12\x35.yandex.cloud.serverless.mdbproxy.v1.ListProxyRequest\x1a\x36.yandex.cloud.serverless.mdbproxy.v1.ListProxyResponse\"\x1c\x82\xd3\xe4\x93\x02\x16\x12\x14/mdbproxy/v1/proxies\x12\xa5\x01\n\x06\x43reate\x12\x37.yandex.cloud.serverless.mdbproxy.v1.CreateProxyRequest\x1a!.yandex.cloud.operation.Operation\"?\xb2\xd2*\x1c\n\x13\x43reateProxyMetadata\x12\x05Proxy\x82\xd3\xe4\x93\x02\x19\"\x14/mdbproxy/v1/proxies:\x01*\x12\xb0\x01\n\x06Update\x12\x37.yandex.cloud.serverless.mdbproxy.v1.UpdateProxyRequest\x1a!.yandex.cloud.operation.Operation\"J\xb2\xd2*\x1c\n\x13UpdateProxyMetadata\x12\x05Proxy\x82\xd3\xe4\x93\x02$2\x1f/mdbproxy/v1/proxies/{proxy_id}:\x01*\x12\xbd\x01\n\x06\x44\x65lete\x12\x37.yandex.cloud.serverless.mdbproxy.v1.DeleteProxyRequest\x1a!.yandex.cloud.operation.Operation\"W\xb2\xd2*,\n\x13\x44\x65leteProxyMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02!*\x1f/mdbproxy/v1/proxies/{proxy_id}\x12\xc7\x01\n\x0eListOperations\x12?.yandex.cloud.serverless.mdbproxy.v1.ListProxyOperationsRequest\x1a@.yandex.cloud.serverless.mdbproxy.v1.ListProxyOperationsResponse\"2\x82\xd3\xe4\x93\x02,\x12*/mdbproxy/v1/proxies/{proxy_id}/operations\x12\xb4\x01\n\x12ListAccessBindings\x12..yandex.cloud.access.ListAccessBindingsRequest\x1a/.yandex.cloud.access.ListAccessBindingsResponse\"=\x82\xd3\xe4\x93\x02\x37\x12\x35/mdbproxy/v1/proxies/{resource_id}:listAccessBindings\x12\xe3\x01\n\x11SetAccessBindings\x12-.yandex.cloud.access.SetAccessBindingsRequest\x1a!.yandex.cloud.operation.Operation\"|\xb2\xd2*9\n access.SetAccessBindingsMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02\x39\"4/mdbproxy/v1/proxies/{resource_id}:setAccessBindings:\x01*\x12\xf0\x01\n\x14UpdateAccessBindings\x12\x30.yandex.cloud.access.UpdateAccessBindingsRequest\x1a!.yandex.cloud.operation.Operation\"\x82\x01\xb2\xd2*<\n#access.UpdateAccessBindingsMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02<27/mdbproxy/v1/proxies/{resource_id}:updateAccessBindings:\x01*Bx\n\'yandex.cloud.api.serverless.mdbproxy.v1ZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/serverless/mdbproxy/v1;proxyb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.serverless.mdbproxy.v1.proxy_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\'yandex.cloud.api.serverless.mdbproxy.v1ZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/serverless/mdbproxy/v1;proxy'
  _GETPROXYREQUEST.fields_by_name['proxy_id']._options = None
  _GETPROXYREQUEST.fields_by_name['proxy_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTPROXYREQUEST.fields_by_name['folder_id']._options = None
  _LISTPROXYREQUEST.fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTPROXYREQUEST.fields_by_name['page_size']._options = None
  _LISTPROXYREQUEST.fields_by_name['page_size']._serialized_options = b'\372\3071\0060-1000'
  _LISTPROXYREQUEST.fields_by_name['page_token']._options = None
  _LISTPROXYREQUEST.fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _LISTPROXYREQUEST.fields_by_name['filter']._options = None
  _LISTPROXYREQUEST.fields_by_name['filter']._serialized_options = b'\212\3101\006<=1000'
  _LISTPROXYRESPONSE.fields_by_name['next_page_token']._options = None
  _LISTPROXYRESPONSE.fields_by_name['next_page_token']._serialized_options = b'\212\3101\005<=100'
  _CREATEPROXYREQUEST_LABELSENTRY._options = None
  _CREATEPROXYREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _CREATEPROXYREQUEST.fields_by_name['folder_id']._options = None
  _CREATEPROXYREQUEST.fields_by_name['folder_id']._serialized_options = b'\350\3071\001'
  _CREATEPROXYREQUEST.fields_by_name['name']._options = None
  _CREATEPROXYREQUEST.fields_by_name['name']._serialized_options = b'\362\3071\035|[a-z][-a-z0-9]{1,61}[a-z0-9]'
  _CREATEPROXYREQUEST.fields_by_name['description']._options = None
  _CREATEPROXYREQUEST.fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _CREATEPROXYREQUEST.fields_by_name['labels']._options = None
  _CREATEPROXYREQUEST.fields_by_name['labels']._serialized_options = b'\362\3071\017[-_./\\@0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\034\022\024[a-z][-_./\\@0-9a-z]*\032\0041-63'
  _CREATEPROXYREQUEST.fields_by_name['target']._options = None
  _CREATEPROXYREQUEST.fields_by_name['target']._serialized_options = b'\350\3071\001'
  _CREATEPROXYMETADATA.fields_by_name['proxy_id']._options = None
  _CREATEPROXYMETADATA.fields_by_name['proxy_id']._serialized_options = b'\212\3101\004<=50'
  _UPDATEPROXYREQUEST_LABELSENTRY._options = None
  _UPDATEPROXYREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _UPDATEPROXYREQUEST.fields_by_name['proxy_id']._options = None
  _UPDATEPROXYREQUEST.fields_by_name['proxy_id']._serialized_options = b'\350\3071\001'
  _UPDATEPROXYREQUEST.fields_by_name['name']._options = None
  _UPDATEPROXYREQUEST.fields_by_name['name']._serialized_options = b'\362\3071\035|[a-z][-a-z0-9]{1,61}[a-z0-9]'
  _UPDATEPROXYREQUEST.fields_by_name['description']._options = None
  _UPDATEPROXYREQUEST.fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _UPDATEPROXYREQUEST.fields_by_name['labels']._options = None
  _UPDATEPROXYREQUEST.fields_by_name['labels']._serialized_options = b'\362\3071\017[-_./\\@0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\034\022\024[a-z][-_./\\@0-9a-z]*\032\0041-63'
  _UPDATEPROXYMETADATA.fields_by_name['proxy_id']._options = None
  _UPDATEPROXYMETADATA.fields_by_name['proxy_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _DELETEPROXYREQUEST.fields_by_name['proxy_id']._options = None
  _DELETEPROXYREQUEST.fields_by_name['proxy_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _DELETEPROXYMETADATA.fields_by_name['proxy_id']._options = None
  _DELETEPROXYMETADATA.fields_by_name['proxy_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTPROXYOPERATIONSREQUEST.fields_by_name['proxy_id']._options = None
  _LISTPROXYOPERATIONSREQUEST.fields_by_name['proxy_id']._serialized_options = b'\350\3071\001'
  _LISTPROXYOPERATIONSREQUEST.fields_by_name['page_size']._options = None
  _LISTPROXYOPERATIONSREQUEST.fields_by_name['page_size']._serialized_options = b'\372\3071\0060-1000'
  _LISTPROXYOPERATIONSREQUEST.fields_by_name['page_token']._options = None
  _LISTPROXYOPERATIONSREQUEST.fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _LISTPROXYOPERATIONSREQUEST.fields_by_name['filter']._options = None
  _LISTPROXYOPERATIONSREQUEST.fields_by_name['filter']._serialized_options = b'\212\3101\006<=1000'
  _PROXYSERVICE.methods_by_name['Get']._options = None
  _PROXYSERVICE.methods_by_name['Get']._serialized_options = b'\202\323\344\223\002!\022\037/mdbproxy/v1/proxies/{proxy_id}'
  _PROXYSERVICE.methods_by_name['List']._options = None
  _PROXYSERVICE.methods_by_name['List']._serialized_options = b'\202\323\344\223\002\026\022\024/mdbproxy/v1/proxies'
  _PROXYSERVICE.methods_by_name['Create']._options = None
  _PROXYSERVICE.methods_by_name['Create']._serialized_options = b'\262\322*\034\n\023CreateProxyMetadata\022\005Proxy\202\323\344\223\002\031\"\024/mdbproxy/v1/proxies:\001*'
  _PROXYSERVICE.methods_by_name['Update']._options = None
  _PROXYSERVICE.methods_by_name['Update']._serialized_options = b'\262\322*\034\n\023UpdateProxyMetadata\022\005Proxy\202\323\344\223\002$2\037/mdbproxy/v1/proxies/{proxy_id}:\001*'
  _PROXYSERVICE.methods_by_name['Delete']._options = None
  _PROXYSERVICE.methods_by_name['Delete']._serialized_options = b'\262\322*,\n\023DeleteProxyMetadata\022\025google.protobuf.Empty\202\323\344\223\002!*\037/mdbproxy/v1/proxies/{proxy_id}'
  _PROXYSERVICE.methods_by_name['ListOperations']._options = None
  _PROXYSERVICE.methods_by_name['ListOperations']._serialized_options = b'\202\323\344\223\002,\022*/mdbproxy/v1/proxies/{proxy_id}/operations'
  _PROXYSERVICE.methods_by_name['ListAccessBindings']._options = None
  _PROXYSERVICE.methods_by_name['ListAccessBindings']._serialized_options = b'\202\323\344\223\0027\0225/mdbproxy/v1/proxies/{resource_id}:listAccessBindings'
  _PROXYSERVICE.methods_by_name['SetAccessBindings']._options = None
  _PROXYSERVICE.methods_by_name['SetAccessBindings']._serialized_options = b'\262\322*9\n access.SetAccessBindingsMetadata\022\025google.protobuf.Empty\202\323\344\223\0029\"4/mdbproxy/v1/proxies/{resource_id}:setAccessBindings:\001*'
  _PROXYSERVICE.methods_by_name['UpdateAccessBindings']._options = None
  _PROXYSERVICE.methods_by_name['UpdateAccessBindings']._serialized_options = b'\262\322*<\n#access.UpdateAccessBindingsMetadata\022\025google.protobuf.Empty\202\323\344\223\002<27/mdbproxy/v1/proxies/{resource_id}:updateAccessBindings:\001*'
  _globals['_GETPROXYREQUEST']._serialized_start=348
  _globals['_GETPROXYREQUEST']._serialized_end=397
  _globals['_LISTPROXYREQUEST']._serialized_start=400
  _globals['_LISTPROXYREQUEST']._serialized_end=541
  _globals['_LISTPROXYRESPONSE']._serialized_start=543
  _globals['_LISTPROXYRESPONSE']._serialized_end=659
  _globals['_CREATEPROXYREQUEST']._serialized_start=662
  _globals['_CREATEPROXYREQUEST']._serialized_end=1057
  _globals['_CREATEPROXYREQUEST_LABELSENTRY']._serialized_start=1012
  _globals['_CREATEPROXYREQUEST_LABELSENTRY']._serialized_end=1057
  _globals['_CREATEPROXYMETADATA']._serialized_start=1059
  _globals['_CREATEPROXYMETADATA']._serialized_end=1108
  _globals['_UPDATEPROXYREQUEST']._serialized_start=1111
  _globals['_UPDATEPROXYREQUEST']._serialized_end=1548
  _globals['_UPDATEPROXYREQUEST_LABELSENTRY']._serialized_start=1012
  _globals['_UPDATEPROXYREQUEST_LABELSENTRY']._serialized_end=1057
  _globals['_UPDATEPROXYMETADATA']._serialized_start=1550
  _globals['_UPDATEPROXYMETADATA']._serialized_end=1603
  _globals['_DELETEPROXYREQUEST']._serialized_start=1605
  _globals['_DELETEPROXYREQUEST']._serialized_end=1657
  _globals['_DELETEPROXYMETADATA']._serialized_start=1659
  _globals['_DELETEPROXYMETADATA']._serialized_end=1712
  _globals['_LISTPROXYOPERATIONSREQUEST']._serialized_start=1715
  _globals['_LISTPROXYOPERATIONSREQUEST']._serialized_end=1857
  _globals['_LISTPROXYOPERATIONSRESPONSE']._serialized_start=1859
  _globals['_LISTPROXYOPERATIONSRESPONSE']._serialized_end=1968
  _globals['_PROXYSERVICE']._serialized_start=1971
  _globals['_PROXYSERVICE']._serialized_end=3679
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class User(google.protobuf.message.Message):
    """A MySQL user. For more information, see the [documentation](/docs/managed-mysql/concepts)."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    CLUSTER_ID_FIELD_NUMBER: builtins.int
    PERMISSIONS_FIELD_NUMBER: builtins.int
    name: builtins.str
    """Name of the MySQL user."""
    cluster_id: builtins.str
    """ID of the MySQL cluster the user belongs to."""
    @property
    def permissions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Permission]:
        """Set of permissions granted to the user."""

    def __init__(
        self,
        *,
        name: builtins.str = ...,
        cluster_id: builtins.str = ...,
        permissions: collections.abc.Iterable[global___Permission] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "name", b"name", "permissions", b"permissions"]) -> None: ...

global___User = User

@typing.final
class Permission(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Privilege:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _PrivilegeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Permission._Privilege.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        PRIVILEGE_UNSPECIFIED: Permission._Privilege.ValueType  # 0
        ALL_PRIVILEGES: Permission._Privilege.ValueType  # 1
        """All privileges that can be made available to the user."""
        ALTER: Permission._Privilege.ValueType  # 2
        """Altering tables."""
        ALTER_ROUTINE: Permission._Privilege.ValueType  # 3
        """Altering stored routines (stored procedures and functions)."""
        CREATE: Permission._Privilege.ValueType  # 4
        """Creating tables or indexes."""
        CREATE_ROUTINE: Permission._Privilege.ValueType  # 5
        """Creating stored routines."""
        CREATE_TEMPORARY_TABLES: Permission._Privilege.ValueType  # 6
        """Creating temporary tables."""
        CREATE_VIEW: Permission._Privilege.ValueType  # 7
        """Creating views."""
        DELETE: Permission._Privilege.ValueType  # 8
        """Deleting tables."""
        DROP: Permission._Privilege.ValueType  # 9
        """Removing tables or views."""
        EVENT: Permission._Privilege.ValueType  # 10
        """Creating, altering, dropping, or displaying events for the Event Scheduler."""
        EXECUTE: Permission._Privilege.ValueType  # 11
        """Executing stored routines."""
        INDEX: Permission._Privilege.ValueType  # 12
        """Creating and removing indexes."""
        INSERT: Permission._Privilege.ValueType  # 13
        """Inserting rows into the database."""
        LOCK_TABLES: Permission._Privilege.ValueType  # 14
        """Using LOCK TABLES statement for tables available with SELECT privilege."""
        SELECT: Permission._Privilege.ValueType  # 15
        """Selecting rows from tables.

        Some SELECT statements can be allowed without the SELECT privilege. All statements that read column values require the SELECT privilege. See details in [MySQL documentation](https://dev.mysql.com/doc/refman/5.7/en/privileges-provided.html#priv_select).
        """
        SHOW_VIEW: Permission._Privilege.ValueType  # 16
        """Using the SHOW CREATE VIEW statement. Also needed for views used with EXPLAIN."""
        TRIGGER: Permission._Privilege.ValueType  # 17
        """Creating, removing, executing, or displaying triggers for a table."""
        UPDATE: Permission._Privilege.ValueType  # 18
        """Updating rows in the database."""

    class Privilege(_Privilege, metaclass=_PrivilegeEnumTypeWrapper): ...
    PRIVILEGE_UNSPECIFIED: Permission.Privilege.ValueType  # 0
    ALL_PRIVILEGES: Permission.Privilege.ValueType  # 1
    """All privileges that can be made available to the user."""
    ALTER: Permission.Privilege.ValueType  # 2
    """Altering tables."""
    ALTER_ROUTINE: Permission.Privilege.ValueType  # 3
    """Altering stored routines (stored procedures and functions)."""
    CREATE: Permission.Privilege.ValueType  # 4
    """Creating tables or indexes."""
    CREATE_ROUTINE: Permission.Privilege.ValueType  # 5
    """Creating stored routines."""
    CREATE_TEMPORARY_TABLES: Permission.Privilege.ValueType  # 6
    """Creating temporary tables."""
    CREATE_VIEW: Permission.Privilege.ValueType  # 7
    """Creating views."""
    DELETE: Permission.Privilege.ValueType  # 8
    """Deleting tables."""
    DROP: Permission.Privilege.ValueType  # 9
    """Removing tables or views."""
    EVENT: Permission.Privilege.ValueType  # 10
    """Creating, altering, dropping, or displaying events for the Event Scheduler."""
    EXECUTE: Permission.Privilege.ValueType  # 11
    """Executing stored routines."""
    INDEX: Permission.Privilege.ValueType  # 12
    """Creating and removing indexes."""
    INSERT: Permission.Privilege.ValueType  # 13
    """Inserting rows into the database."""
    LOCK_TABLES: Permission.Privilege.ValueType  # 14
    """Using LOCK TABLES statement for tables available with SELECT privilege."""
    SELECT: Permission.Privilege.ValueType  # 15
    """Selecting rows from tables.

    Some SELECT statements can be allowed without the SELECT privilege. All statements that read column values require the SELECT privilege. See details in [MySQL documentation](https://dev.mysql.com/doc/refman/5.7/en/privileges-provided.html#priv_select).
    """
    SHOW_VIEW: Permission.Privilege.ValueType  # 16
    """Using the SHOW CREATE VIEW statement. Also needed for views used with EXPLAIN."""
    TRIGGER: Permission.Privilege.ValueType  # 17
    """Creating, removing, executing, or displaying triggers for a table."""
    UPDATE: Permission.Privilege.ValueType  # 18
    """Updating rows in the database."""

    DATABASE_NAME_FIELD_NUMBER: builtins.int
    ROLES_FIELD_NUMBER: builtins.int
    database_name: builtins.str
    """Name of the database that the permission grants access to."""
    @property
    def roles(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[global___Permission.Privilege.ValueType]:
        """Roles granted to the user within the database."""

    def __init__(
        self,
        *,
        database_name: builtins.str = ...,
        roles: collections.abc.Iterable[global___Permission.Privilege.ValueType] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["database_name", b"database_name", "roles", b"roles"]) -> None: ...

global___Permission = Permission

@typing.final
class UserSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    PASSWORD_FIELD_NUMBER: builtins.int
    PERMISSIONS_FIELD_NUMBER: builtins.int
    name: builtins.str
    """Name of the MySQL user."""
    password: builtins.str
    """Password of the MySQL user."""
    @property
    def permissions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Permission]:
        """Set of permissions to grant to the user."""

    def __init__(
        self,
        *,
        name: builtins.str = ...,
        password: builtins.str = ...,
        permissions: collections.abc.Iterable[global___Permission] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["name", b"name", "password", b"password", "permissions", b"permissions"]) -> None: ...

global___UserSpec = UserSpec



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class PutEventRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BUS_ID_FIELD_NUMBER: builtins.int
    BODY_FIELD_NUMBER: builtins.int
    bus_id: builtins.str
    """ID of the bus to put event."""
    body: builtins.str
    """Event body."""
    def __init__(
        self,
        *,
        bus_id: builtins.str = ...,
        body: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["body", b"body", "bus_id", b"bus_id"]) -> None: ...

global___PutEventRequest = PutEventRequest



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/cloudapps/workload/v1/cloud_application_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from yandex.cloud.cloudapps.workload.v1 import cloud_application_pb2 as yandex_dot_cloud_dot_cloudapps_dot_workload_dot_v1_dot_cloud__application__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nByandex/cloud/cloudapps/workload/v1/cloud_application_service.proto\x12\"yandex.cloud.cloudapps.workload.v1\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1dyandex/cloud/validation.proto\x1a:yandex/cloud/cloudapps/workload/v1/cloud_application.proto\"\xea\x01\n\x18ResolveByWorkloadRequest\x12\x66\n\rworkload_type\x18\x01 \x01(\x0e\x32I.yandex.cloud.cloudapps.workload.v1.ResolveByWorkloadRequest.WorkloadTypeB\x04\xe8\xc7\x31\x01\x12!\n\x0bworkload_id\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"C\n\x0cWorkloadType\x12\x1d\n\x19WORKLOAD_TYPE_UNSPECIFIED\x10\x00\x12\x14\n\x10\x43OMPUTE_INSTANCE\x10\x01\"l\n\x19ResolveByWorkloadResponse\x12O\n\x11\x63loud_application\x18\x01 \x01(\x0b\x32\x34.yandex.cloud.cloudapps.workload.v1.CloudApplication2\x85\x02\n\x17\x43loudApplicationService\x12U\n\x03Get\x12\x16.google.protobuf.Empty\x1a\x34.yandex.cloud.cloudapps.workload.v1.CloudApplication\"\x00\x12\x92\x01\n\x11ResolveByWorkload\x12<.yandex.cloud.cloudapps.workload.v1.ResolveByWorkloadRequest\x1a=.yandex.cloud.cloudapps.workload.v1.ResolveByWorkloadResponse\"\x00\x42y\n&yandex.cloud.api.cloudapps.workload.v1ZOgithub.com/yandex-cloud/go-genproto/yandex/cloud/cloudapps/workload/v1;workloadb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.cloudapps.workload.v1.cloud_application_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n&yandex.cloud.api.cloudapps.workload.v1ZOgithub.com/yandex-cloud/go-genproto/yandex/cloud/cloudapps/workload/v1;workload'
  _RESOLVEBYWORKLOADREQUEST.fields_by_name['workload_type']._options = None
  _RESOLVEBYWORKLOADREQUEST.fields_by_name['workload_type']._serialized_options = b'\350\3071\001'
  _RESOLVEBYWORKLOADREQUEST.fields_by_name['workload_id']._options = None
  _RESOLVEBYWORKLOADREQUEST.fields_by_name['workload_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_RESOLVEBYWORKLOADREQUEST']._serialized_start=227
  _globals['_RESOLVEBYWORKLOADREQUEST']._serialized_end=461
  _globals['_RESOLVEBYWORKLOADREQUEST_WORKLOADTYPE']._serialized_start=394
  _globals['_RESOLVEBYWORKLOADREQUEST_WORKLOADTYPE']._serialized_end=461
  _globals['_RESOLVEBYWORKLOADRESPONSE']._serialized_start=463
  _globals['_RESOLVEBYWORKLOADRESPONSE']._serialized_end=571
  _globals['_CLOUDAPPLICATIONSERVICE']._serialized_start=574
  _globals['_CLOUDAPPLICATIONSERVICE']._serialized_end=835
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.ai.ocr.v1.ocr_service_pb2
import yandex.cloud.operation.operation_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class TextRecognitionServiceStub:
    """A set of methods for the Vision OCR service."""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    Recognize: grpc.UnaryStreamMultiCallable[
        yandex.cloud.ai.ocr.v1.ocr_service_pb2.RecognizeTextRequest,
        yandex.cloud.ai.ocr.v1.ocr_service_pb2.RecognizeTextResponse,
    ]
    """To send the image for text recognition."""

class TextRecognitionServiceAsyncStub:
    """A set of methods for the Vision OCR service."""

    Recognize: grpc.aio.UnaryStreamMultiCallable[
        yandex.cloud.ai.ocr.v1.ocr_service_pb2.RecognizeTextRequest,
        yandex.cloud.ai.ocr.v1.ocr_service_pb2.RecognizeTextResponse,
    ]
    """To send the image for text recognition."""

class TextRecognitionServiceServicer(metaclass=abc.ABCMeta):
    """A set of methods for the Vision OCR service."""

    @abc.abstractmethod
    def Recognize(
        self,
        request: yandex.cloud.ai.ocr.v1.ocr_service_pb2.RecognizeTextRequest,
        context: _ServicerContext,
    ) -> typing.Union[collections.abc.Iterator[yandex.cloud.ai.ocr.v1.ocr_service_pb2.RecognizeTextResponse], collections.abc.AsyncIterator[yandex.cloud.ai.ocr.v1.ocr_service_pb2.RecognizeTextResponse]]:
        """To send the image for text recognition."""

def add_TextRecognitionServiceServicer_to_server(servicer: TextRecognitionServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...

class TextRecognitionAsyncServiceStub:
    """A set of methods for managing operations for asynchronous API requests."""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    Recognize: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.ai.ocr.v1.ocr_service_pb2.RecognizeTextRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """To send the image for asynchronous text recognition."""

    GetRecognition: grpc.UnaryStreamMultiCallable[
        yandex.cloud.ai.ocr.v1.ocr_service_pb2.GetRecognitionRequest,
        yandex.cloud.ai.ocr.v1.ocr_service_pb2.RecognizeTextResponse,
    ]
    """To get recognition results."""

class TextRecognitionAsyncServiceAsyncStub:
    """A set of methods for managing operations for asynchronous API requests."""

    Recognize: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.ai.ocr.v1.ocr_service_pb2.RecognizeTextRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """To send the image for asynchronous text recognition."""

    GetRecognition: grpc.aio.UnaryStreamMultiCallable[
        yandex.cloud.ai.ocr.v1.ocr_service_pb2.GetRecognitionRequest,
        yandex.cloud.ai.ocr.v1.ocr_service_pb2.RecognizeTextResponse,
    ]
    """To get recognition results."""

class TextRecognitionAsyncServiceServicer(metaclass=abc.ABCMeta):
    """A set of methods for managing operations for asynchronous API requests."""

    @abc.abstractmethod
    def Recognize(
        self,
        request: yandex.cloud.ai.ocr.v1.ocr_service_pb2.RecognizeTextRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """To send the image for asynchronous text recognition."""

    @abc.abstractmethod
    def GetRecognition(
        self,
        request: yandex.cloud.ai.ocr.v1.ocr_service_pb2.GetRecognitionRequest,
        context: _ServicerContext,
    ) -> typing.Union[collections.abc.Iterator[yandex.cloud.ai.ocr.v1.ocr_service_pb2.RecognizeTextResponse], collections.abc.AsyncIterator[yandex.cloud.ai.ocr.v1.ocr_service_pb2.RecognizeTextResponse]]:
        """To get recognition results."""

def add_TextRecognitionAsyncServiceServicer_to_server(servicer: TextRecognitionAsyncServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class PrivateEndpoint(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Status:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _StatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[PrivateEndpoint._Status.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        STATUS_UNSPECIFIED: PrivateEndpoint._Status.ValueType  # 0
        PENDING: PrivateEndpoint._Status.ValueType  # 1
        """Private endpoint is still creating / updating."""
        AVAILABLE: PrivateEndpoint._Status.ValueType  # 2
        """Private endpoint is available."""
        DELETING: PrivateEndpoint._Status.ValueType  # 3
        """Private endpoint is deleting."""

    class Status(_Status, metaclass=_StatusEnumTypeWrapper):
        """Status of the private endpoint."""

    STATUS_UNSPECIFIED: PrivateEndpoint.Status.ValueType  # 0
    PENDING: PrivateEndpoint.Status.ValueType  # 1
    """Private endpoint is still creating / updating."""
    AVAILABLE: PrivateEndpoint.Status.ValueType  # 2
    """Private endpoint is available."""
    DELETING: PrivateEndpoint.Status.ValueType  # 3
    """Private endpoint is deleting."""

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing.final
    class ObjectStorage(google.protobuf.message.Message):
        """Yandex Cloud Object Storage."""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        def __init__(
            self,
        ) -> None: ...

    @typing.final
    class DnsOptions(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        PRIVATE_DNS_RECORDS_ENABLED_FIELD_NUMBER: builtins.int
        private_dns_records_enabled: builtins.bool
        """If enabled - vpc will create private dns records for specified service."""
        def __init__(
            self,
            *,
            private_dns_records_enabled: builtins.bool = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["private_dns_records_enabled", b"private_dns_records_enabled"]) -> None: ...

    @typing.final
    class EndpointAddress(google.protobuf.message.Message):
        """Private endpoint ip address details."""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        SUBNET_ID_FIELD_NUMBER: builtins.int
        ADDRESS_FIELD_NUMBER: builtins.int
        ADDRESS_ID_FIELD_NUMBER: builtins.int
        subnet_id: builtins.str
        """ID of the subnet that the private endpoint address belongs to."""
        address: builtins.str
        """IP address of the private endpoint."""
        address_id: builtins.str
        """ID of the private endpoint address."""
        def __init__(
            self,
            *,
            subnet_id: builtins.str = ...,
            address: builtins.str = ...,
            address_id: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["address", b"address", "address_id", b"address_id", "subnet_id", b"subnet_id"]) -> None: ...

    ID_FIELD_NUMBER: builtins.int
    FOLDER_ID_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    NETWORK_ID_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    ADDRESS_FIELD_NUMBER: builtins.int
    DNS_OPTIONS_FIELD_NUMBER: builtins.int
    OBJECT_STORAGE_FIELD_NUMBER: builtins.int
    id: builtins.str
    """ID of the private endpoint. Generated at creation time."""
    folder_id: builtins.str
    """ID of the folder that the private endpoint belongs to."""
    name: builtins.str
    """Name of the private endpoint.
    The name is unique within the folder.
    Value must match the regular expression
    ``\\|[a-zA-Z]([-_a-zA-Z0-9]{0,61}[a-zA-Z0-9])?``.
    """
    description: builtins.str
    """Description of the private endpoint. 0-256 characters long."""
    network_id: builtins.str
    """ID of the network that the private endpoint belongs to."""
    status: global___PrivateEndpoint.Status.ValueType
    """Status of the private endpoint."""
    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Creation timestamp."""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Private endpoint labels as `key:value` pairs.
        No more than 64 per resource.
        The maximum string length in characters for each value is 63.
        Each value must match the regular expression `[-_0-9a-z]*`.
        The string length in characters for each key must be 1-63.
        Each key must match the regular expression `[a-z][-_0-9a-z]*`.
        """

    @property
    def address(self) -> global___PrivateEndpoint.EndpointAddress:
        """Private endpoint ip address details."""

    @property
    def dns_options(self) -> global___PrivateEndpoint.DnsOptions:
        """Private endpoint dns options."""

    @property
    def object_storage(self) -> global___PrivateEndpoint.ObjectStorage:
        """Yandex Cloud Object Storage."""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        folder_id: builtins.str = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        network_id: builtins.str = ...,
        status: global___PrivateEndpoint.Status.ValueType = ...,
        address: global___PrivateEndpoint.EndpointAddress | None = ...,
        dns_options: global___PrivateEndpoint.DnsOptions | None = ...,
        object_storage: global___PrivateEndpoint.ObjectStorage | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["address", b"address", "created_at", b"created_at", "dns_options", b"dns_options", "object_storage", b"object_storage", "service", b"service"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["address", b"address", "created_at", b"created_at", "description", b"description", "dns_options", b"dns_options", "folder_id", b"folder_id", "id", b"id", "labels", b"labels", "name", b"name", "network_id", b"network_id", "object_storage", b"object_storage", "service", b"service", "status", b"status"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["service", b"service"]) -> typing.Literal["object_storage"] | None: ...

global___PrivateEndpoint = PrivateEndpoint



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.mdb.elasticsearch.v1.auth_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class ListAuthProvidersRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """Required. ID of the ElasticSearch cluster."""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id"]) -> None: ...

global___ListAuthProvidersRequest = ListAuthProvidersRequest

@typing.final
class ListAuthProvidersResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PROVIDERS_FIELD_NUMBER: builtins.int
    @property
    def providers(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.mdb.elasticsearch.v1.auth_pb2.AuthProvider]:
        """List of auth providers of the Elasticsearch cluster."""

    def __init__(
        self,
        *,
        providers: collections.abc.Iterable[yandex.cloud.mdb.elasticsearch.v1.auth_pb2.AuthProvider] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["providers", b"providers"]) -> None: ...

global___ListAuthProvidersResponse = ListAuthProvidersResponse

@typing.final
class GetAuthProviderRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """Required. ID of the ElasticSearch cluster."""
    name: builtins.str
    """Required. Name of the provider to delete."""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "name", b"name"]) -> None: ...

global___GetAuthProviderRequest = GetAuthProviderRequest

@typing.final
class AddAuthProvidersRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    PROVIDERS_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """Required. ID of the ElasticSearch cluster."""
    @property
    def providers(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.mdb.elasticsearch.v1.auth_pb2.AuthProvider]:
        """Required. List of providers to add."""

    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        providers: collections.abc.Iterable[yandex.cloud.mdb.elasticsearch.v1.auth_pb2.AuthProvider] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "providers", b"providers"]) -> None: ...

global___AddAuthProvidersRequest = AddAuthProvidersRequest

@typing.final
class UpdateAuthProvidersRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    PROVIDERS_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """Required. ID of the ElasticSearch cluster."""
    @property
    def providers(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.mdb.elasticsearch.v1.auth_pb2.AuthProvider]:
        """Required. List of providers to set."""

    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        providers: collections.abc.Iterable[yandex.cloud.mdb.elasticsearch.v1.auth_pb2.AuthProvider] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "providers", b"providers"]) -> None: ...

global___UpdateAuthProvidersRequest = UpdateAuthProvidersRequest

@typing.final
class DeleteAuthProvidersRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    PROVIDER_NAMES_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """Required. ID of the ElasticSearch cluster."""
    @property
    def provider_names(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Required. List of providers to delete."""

    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        provider_names: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "provider_names", b"provider_names"]) -> None: ...

global___DeleteAuthProvidersRequest = DeleteAuthProvidersRequest

@typing.final
class UpdateAuthProviderRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROVIDER_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """Required. ID of the ElasticSearch cluster."""
    name: builtins.str
    """Required. Name of the provider to update."""
    @property
    def provider(self) -> yandex.cloud.mdb.elasticsearch.v1.auth_pb2.AuthProvider:
        """Required. New provider defenition."""

    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        name: builtins.str = ...,
        provider: yandex.cloud.mdb.elasticsearch.v1.auth_pb2.AuthProvider | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["provider", b"provider"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "name", b"name", "provider", b"provider"]) -> None: ...

global___UpdateAuthProviderRequest = UpdateAuthProviderRequest

@typing.final
class DeleteAuthProviderRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """Required. ID of the ElasticSearch cluster."""
    name: builtins.str
    """Required. Name of the provider to delete."""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "name", b"name"]) -> None: ...

global___DeleteAuthProviderRequest = DeleteAuthProviderRequest

@typing.final
class AddAuthProvidersMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    NAMES_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the ElasticSearch cluster."""
    @property
    def names(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Names of the providers being added."""

    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        names: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "names", b"names"]) -> None: ...

global___AddAuthProvidersMetadata = AddAuthProvidersMetadata

@typing.final
class UpdateAuthProvidersMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    NAMES_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the ElasticSearch cluster."""
    @property
    def names(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Names of the providers being added."""

    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        names: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "names", b"names"]) -> None: ...

global___UpdateAuthProvidersMetadata = UpdateAuthProvidersMetadata

@typing.final
class DeleteAuthProvidersMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    NAMES_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the ElasticSearch cluster."""
    @property
    def names(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Names of the providers being removed."""

    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        names: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "names", b"names"]) -> None: ...

global___DeleteAuthProvidersMetadata = DeleteAuthProvidersMetadata



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _Status:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _StatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_Status.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    STATUS_UNSPECIFIED: _Status.ValueType  # 0
    """Status is unspecified."""
    CREATED: _Status.ValueType  # 1
    """Test has been created, but not started by any agent."""
    INITIATED: _Status.ValueType  # 2
    """Execution stage: initialization."""
    PREPARING: _Status.ValueType  # 3
    """Execution stage: data preparation and warm-up."""
    RUNNING: _Status.ValueType  # 4
    """Execution stage: load generation."""
    FINISHING: _Status.ValueType  # 5
    """Execution stage: termination."""
    DONE: _Status.ValueType  # 6
    """Test is done."""
    POST_PROCESSING: _Status.ValueType  # 7
    """Execution stage: results post-processing."""
    FAILED: _Status.ValueType  # 8
    """Test has failed due to some error."""
    STOPPING: _Status.ValueType  # 9
    """Test is being stopped."""
    STOPPED: _Status.ValueType  # 10
    """Test has been stopped."""
    AUTOSTOPPED: _Status.ValueType  # 11
    """Test has been stopped automatically by satisfying autostop condition."""
    WAITING: _Status.ValueType  # 12
    """Execution stage: waiting for a trigger to start."""
    DELETING: _Status.ValueType  # 13
    """Test is being deleted."""
    LOST: _Status.ValueType  # 14
    """Test status has not been reported in a while during execution stage.

    Means that either an agent is too busy to send it, got offline, or failed without
    reporting a final status.
    """

class Status(_Status, metaclass=_StatusEnumTypeWrapper): ...

STATUS_UNSPECIFIED: Status.ValueType  # 0
"""Status is unspecified."""
CREATED: Status.ValueType  # 1
"""Test has been created, but not started by any agent."""
INITIATED: Status.ValueType  # 2
"""Execution stage: initialization."""
PREPARING: Status.ValueType  # 3
"""Execution stage: data preparation and warm-up."""
RUNNING: Status.ValueType  # 4
"""Execution stage: load generation."""
FINISHING: Status.ValueType  # 5
"""Execution stage: termination."""
DONE: Status.ValueType  # 6
"""Test is done."""
POST_PROCESSING: Status.ValueType  # 7
"""Execution stage: results post-processing."""
FAILED: Status.ValueType  # 8
"""Test has failed due to some error."""
STOPPING: Status.ValueType  # 9
"""Test is being stopped."""
STOPPED: Status.ValueType  # 10
"""Test has been stopped."""
AUTOSTOPPED: Status.ValueType  # 11
"""Test has been stopped automatically by satisfying autostop condition."""
WAITING: Status.ValueType  # 12
"""Execution stage: waiting for a trigger to start."""
DELETING: Status.ValueType  # 13
"""Test is being deleted."""
LOST: Status.ValueType  # 14
"""Test status has not been reported in a while during execution stage.

Means that either an agent is too busy to send it, got offline, or failed without
reporting a final status.
"""
global___Status = Status



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys
import typing
import yandex.cloud.ydb.v1.backup_pb2

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _AlertEvaluationStatus:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _AlertEvaluationStatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_AlertEvaluationStatus.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    ALERT_EVALUATION_STATUS_UNSPECIFIED: _AlertEvaluationStatus.ValueType  # 0
    ALERT_EVALUATION_STATUS_OK: _AlertEvaluationStatus.ValueType  # 1
    ALERT_EVALUATION_STATUS_NO_DATA: _AlertEvaluationStatus.ValueType  # 2
    ALERT_EVALUATION_STATUS_ERROR: _AlertEvaluationStatus.ValueType  # 3
    ALERT_EVALUATION_STATUS_ALARM: _AlertEvaluationStatus.ValueType  # 4
    ALERT_EVALUATION_STATUS_WARN: _AlertEvaluationStatus.ValueType  # 5

class AlertEvaluationStatus(_AlertEvaluationStatus, metaclass=_AlertEvaluationStatusEnumTypeWrapper): ...

ALERT_EVALUATION_STATUS_UNSPECIFIED: AlertEvaluationStatus.ValueType  # 0
ALERT_EVALUATION_STATUS_OK: AlertEvaluationStatus.ValueType  # 1
ALERT_EVALUATION_STATUS_NO_DATA: AlertEvaluationStatus.ValueType  # 2
ALERT_EVALUATION_STATUS_ERROR: AlertEvaluationStatus.ValueType  # 3
ALERT_EVALUATION_STATUS_ALARM: AlertEvaluationStatus.ValueType  # 4
ALERT_EVALUATION_STATUS_WARN: AlertEvaluationStatus.ValueType  # 5
global___AlertEvaluationStatus = AlertEvaluationStatus

@typing.final
class Database(google.protobuf.message.Message):
    """YDB database."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Status:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _StatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Database._Status.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        STATUS_UNSPECIFIED: Database._Status.ValueType  # 0
        PROVISIONING: Database._Status.ValueType  # 1
        RUNNING: Database._Status.ValueType  # 2
        UPDATING: Database._Status.ValueType  # 4
        ERROR: Database._Status.ValueType  # 5
        DELETING: Database._Status.ValueType  # 6
        STARTING: Database._Status.ValueType  # 7
        STOPPED: Database._Status.ValueType  # 8

    class Status(_Status, metaclass=_StatusEnumTypeWrapper): ...
    STATUS_UNSPECIFIED: Database.Status.ValueType  # 0
    PROVISIONING: Database.Status.ValueType  # 1
    RUNNING: Database.Status.ValueType  # 2
    UPDATING: Database.Status.ValueType  # 4
    ERROR: Database.Status.ValueType  # 5
    DELETING: Database.Status.ValueType  # 6
    STARTING: Database.Status.ValueType  # 7
    STOPPED: Database.Status.ValueType  # 8

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    ID_FIELD_NUMBER: builtins.int
    FOLDER_ID_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    ENDPOINT_FIELD_NUMBER: builtins.int
    RESOURCE_PRESET_ID_FIELD_NUMBER: builtins.int
    STORAGE_CONFIG_FIELD_NUMBER: builtins.int
    SCALE_POLICY_FIELD_NUMBER: builtins.int
    NETWORK_ID_FIELD_NUMBER: builtins.int
    SUBNET_IDS_FIELD_NUMBER: builtins.int
    ZONAL_DATABASE_FIELD_NUMBER: builtins.int
    REGIONAL_DATABASE_FIELD_NUMBER: builtins.int
    DEDICATED_DATABASE_FIELD_NUMBER: builtins.int
    SERVERLESS_DATABASE_FIELD_NUMBER: builtins.int
    ASSIGN_PUBLIC_IPS_FIELD_NUMBER: builtins.int
    LOCATION_ID_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    BACKUP_CONFIG_FIELD_NUMBER: builtins.int
    DOCUMENT_API_ENDPOINT_FIELD_NUMBER: builtins.int
    KINESIS_API_ENDPOINT_FIELD_NUMBER: builtins.int
    KAFKA_API_ENDPOINT_FIELD_NUMBER: builtins.int
    MONITORING_CONFIG_FIELD_NUMBER: builtins.int
    DELETION_PROTECTION_FIELD_NUMBER: builtins.int
    id: builtins.str
    folder_id: builtins.str
    name: builtins.str
    description: builtins.str
    status: global___Database.Status.ValueType
    endpoint: builtins.str
    resource_preset_id: builtins.str
    network_id: builtins.str
    assign_public_ips: builtins.bool
    location_id: builtins.str
    document_api_endpoint: builtins.str
    kinesis_api_endpoint: builtins.str
    kafka_api_endpoint: builtins.str
    deletion_protection: builtins.bool
    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def storage_config(self) -> global___StorageConfig: ...
    @property
    def scale_policy(self) -> global___ScalePolicy: ...
    @property
    def subnet_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def zonal_database(self) -> global___ZonalDatabase:
        """deprecated field"""

    @property
    def regional_database(self) -> global___RegionalDatabase:
        """deprecated field"""

    @property
    def dedicated_database(self) -> global___DedicatedDatabase: ...
    @property
    def serverless_database(self) -> global___ServerlessDatabase: ...
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def backup_config(self) -> yandex.cloud.ydb.v1.backup_pb2.BackupConfig: ...
    @property
    def monitoring_config(self) -> global___MonitoringConfig: ...
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        folder_id: builtins.str = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        status: global___Database.Status.ValueType = ...,
        endpoint: builtins.str = ...,
        resource_preset_id: builtins.str = ...,
        storage_config: global___StorageConfig | None = ...,
        scale_policy: global___ScalePolicy | None = ...,
        network_id: builtins.str = ...,
        subnet_ids: collections.abc.Iterable[builtins.str] | None = ...,
        zonal_database: global___ZonalDatabase | None = ...,
        regional_database: global___RegionalDatabase | None = ...,
        dedicated_database: global___DedicatedDatabase | None = ...,
        serverless_database: global___ServerlessDatabase | None = ...,
        assign_public_ips: builtins.bool = ...,
        location_id: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        backup_config: yandex.cloud.ydb.v1.backup_pb2.BackupConfig | None = ...,
        document_api_endpoint: builtins.str = ...,
        kinesis_api_endpoint: builtins.str = ...,
        kafka_api_endpoint: builtins.str = ...,
        monitoring_config: global___MonitoringConfig | None = ...,
        deletion_protection: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["backup_config", b"backup_config", "created_at", b"created_at", "database_type", b"database_type", "dedicated_database", b"dedicated_database", "monitoring_config", b"monitoring_config", "regional_database", b"regional_database", "scale_policy", b"scale_policy", "serverless_database", b"serverless_database", "storage_config", b"storage_config", "zonal_database", b"zonal_database"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["assign_public_ips", b"assign_public_ips", "backup_config", b"backup_config", "created_at", b"created_at", "database_type", b"database_type", "dedicated_database", b"dedicated_database", "deletion_protection", b"deletion_protection", "description", b"description", "document_api_endpoint", b"document_api_endpoint", "endpoint", b"endpoint", "folder_id", b"folder_id", "id", b"id", "kafka_api_endpoint", b"kafka_api_endpoint", "kinesis_api_endpoint", b"kinesis_api_endpoint", "labels", b"labels", "location_id", b"location_id", "monitoring_config", b"monitoring_config", "name", b"name", "network_id", b"network_id", "regional_database", b"regional_database", "resource_preset_id", b"resource_preset_id", "scale_policy", b"scale_policy", "serverless_database", b"serverless_database", "status", b"status", "storage_config", b"storage_config", "subnet_ids", b"subnet_ids", "zonal_database", b"zonal_database"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["database_type", b"database_type"]) -> typing.Literal["zonal_database", "regional_database", "dedicated_database", "serverless_database"] | None: ...

global___Database = Database

@typing.final
class AlertParameter(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class DoubleParameterValue(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        NAME_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        name: builtins.str
        """Required. Parameter name"""
        value: builtins.float
        """Required. Parameter value"""
        def __init__(
            self,
            *,
            name: builtins.str = ...,
            value: builtins.float = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["name", b"name", "value", b"value"]) -> None: ...

    @typing.final
    class IntegerParameterValue(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        NAME_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        name: builtins.str
        """Required. Parameter name"""
        value: builtins.int
        """Required. Parameter value"""
        def __init__(
            self,
            *,
            name: builtins.str = ...,
            value: builtins.int = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["name", b"name", "value", b"value"]) -> None: ...

    @typing.final
    class TextParameterValue(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        NAME_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        name: builtins.str
        """Required. Parameter name"""
        value: builtins.str
        """Required. Parameter value"""
        def __init__(
            self,
            *,
            name: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["name", b"name", "value", b"value"]) -> None: ...

    @typing.final
    class TextListParameterValue(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        NAME_FIELD_NUMBER: builtins.int
        VALUES_FIELD_NUMBER: builtins.int
        name: builtins.str
        """Required. Parameter name"""
        @property
        def values(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
            """Required. Parameter value"""

        def __init__(
            self,
            *,
            name: builtins.str = ...,
            values: collections.abc.Iterable[builtins.str] | None = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["name", b"name", "values", b"values"]) -> None: ...

    @typing.final
    class LabelListParameterValue(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        NAME_FIELD_NUMBER: builtins.int
        VALUES_FIELD_NUMBER: builtins.int
        name: builtins.str
        """Required. Parameter name"""
        @property
        def values(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
            """Required. Parameter value"""

        def __init__(
            self,
            *,
            name: builtins.str = ...,
            values: collections.abc.Iterable[builtins.str] | None = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["name", b"name", "values", b"values"]) -> None: ...

    DOUBLE_PARAMETER_VALUE_FIELD_NUMBER: builtins.int
    INTEGER_PARAMETER_VALUE_FIELD_NUMBER: builtins.int
    TEXT_PARAMETER_VALUE_FIELD_NUMBER: builtins.int
    TEXT_LIST_PARAMETER_VALUE_FIELD_NUMBER: builtins.int
    LABEL_LIST_PARAMETER_VALUE_FIELD_NUMBER: builtins.int
    @property
    def double_parameter_value(self) -> global___AlertParameter.DoubleParameterValue: ...
    @property
    def integer_parameter_value(self) -> global___AlertParameter.IntegerParameterValue: ...
    @property
    def text_parameter_value(self) -> global___AlertParameter.TextParameterValue: ...
    @property
    def text_list_parameter_value(self) -> global___AlertParameter.TextListParameterValue: ...
    @property
    def label_list_parameter_value(self) -> global___AlertParameter.LabelListParameterValue: ...
    def __init__(
        self,
        *,
        double_parameter_value: global___AlertParameter.DoubleParameterValue | None = ...,
        integer_parameter_value: global___AlertParameter.IntegerParameterValue | None = ...,
        text_parameter_value: global___AlertParameter.TextParameterValue | None = ...,
        text_list_parameter_value: global___AlertParameter.TextListParameterValue | None = ...,
        label_list_parameter_value: global___AlertParameter.LabelListParameterValue | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["double_parameter_value", b"double_parameter_value", "integer_parameter_value", b"integer_parameter_value", "label_list_parameter_value", b"label_list_parameter_value", "parameter", b"parameter", "text_list_parameter_value", b"text_list_parameter_value", "text_parameter_value", b"text_parameter_value"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["double_parameter_value", b"double_parameter_value", "integer_parameter_value", b"integer_parameter_value", "label_list_parameter_value", b"label_list_parameter_value", "parameter", b"parameter", "text_list_parameter_value", b"text_list_parameter_value", "text_parameter_value", b"text_parameter_value"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["parameter", b"parameter"]) -> typing.Literal["double_parameter_value", "integer_parameter_value", "text_parameter_value", "text_list_parameter_value", "label_list_parameter_value"] | None: ...

global___AlertParameter = AlertParameter

@typing.final
class NotificationChannel(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NOTIFICATION_CHANNEL_ID_FIELD_NUMBER: builtins.int
    NOTIFY_ABOUT_STATUSES_FIELD_NUMBER: builtins.int
    REPEATE_NOTIFY_DELAY_MS_FIELD_NUMBER: builtins.int
    notification_channel_id: builtins.str
    repeate_notify_delay_ms: builtins.int
    @property
    def notify_about_statuses(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[global___AlertEvaluationStatus.ValueType]: ...
    def __init__(
        self,
        *,
        notification_channel_id: builtins.str = ...,
        notify_about_statuses: collections.abc.Iterable[global___AlertEvaluationStatus.ValueType] | None = ...,
        repeate_notify_delay_ms: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["notification_channel_id", b"notification_channel_id", "notify_about_statuses", b"notify_about_statuses", "repeate_notify_delay_ms", b"repeate_notify_delay_ms"]) -> None: ...

global___NotificationChannel = NotificationChannel

@typing.final
class Alert(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ALERT_ID_FIELD_NUMBER: builtins.int
    ALERT_TEMPLATE_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    NOTIFICATION_CHANNELS_FIELD_NUMBER: builtins.int
    ALERT_PARAMETERS_FIELD_NUMBER: builtins.int
    ALERT_THRESHOLDS_FIELD_NUMBER: builtins.int
    alert_id: builtins.str
    """output only field."""
    alert_template_id: builtins.str
    """template of the alert."""
    name: builtins.str
    """name of the alert."""
    description: builtins.str
    """human readable description of the alert."""
    @property
    def notification_channels(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___NotificationChannel]:
        """the notification channels of the alert."""

    @property
    def alert_parameters(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___AlertParameter]:
        """alert parameters to override."""

    @property
    def alert_thresholds(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___AlertParameter]:
        """alert paratemers to override."""

    def __init__(
        self,
        *,
        alert_id: builtins.str = ...,
        alert_template_id: builtins.str = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        notification_channels: collections.abc.Iterable[global___NotificationChannel] | None = ...,
        alert_parameters: collections.abc.Iterable[global___AlertParameter] | None = ...,
        alert_thresholds: collections.abc.Iterable[global___AlertParameter] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["alert_id", b"alert_id", "alert_parameters", b"alert_parameters", "alert_template_id", b"alert_template_id", "alert_thresholds", b"alert_thresholds", "description", b"description", "name", b"name", "notification_channels", b"notification_channels"]) -> None: ...

global___Alert = Alert

@typing.final
class MonitoringConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ALERTS_FIELD_NUMBER: builtins.int
    @property
    def alerts(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Alert]: ...
    def __init__(
        self,
        *,
        alerts: collections.abc.Iterable[global___Alert] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["alerts", b"alerts"]) -> None: ...

global___MonitoringConfig = MonitoringConfig

@typing.final
class DedicatedDatabase(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_PRESET_ID_FIELD_NUMBER: builtins.int
    STORAGE_CONFIG_FIELD_NUMBER: builtins.int
    SCALE_POLICY_FIELD_NUMBER: builtins.int
    NETWORK_ID_FIELD_NUMBER: builtins.int
    SUBNET_IDS_FIELD_NUMBER: builtins.int
    ASSIGN_PUBLIC_IPS_FIELD_NUMBER: builtins.int
    resource_preset_id: builtins.str
    network_id: builtins.str
    assign_public_ips: builtins.bool
    @property
    def storage_config(self) -> global___StorageConfig: ...
    @property
    def scale_policy(self) -> global___ScalePolicy: ...
    @property
    def subnet_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        resource_preset_id: builtins.str = ...,
        storage_config: global___StorageConfig | None = ...,
        scale_policy: global___ScalePolicy | None = ...,
        network_id: builtins.str = ...,
        subnet_ids: collections.abc.Iterable[builtins.str] | None = ...,
        assign_public_ips: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["scale_policy", b"scale_policy", "storage_config", b"storage_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["assign_public_ips", b"assign_public_ips", "network_id", b"network_id", "resource_preset_id", b"resource_preset_id", "scale_policy", b"scale_policy", "storage_config", b"storage_config", "subnet_ids", b"subnet_ids"]) -> None: ...

global___DedicatedDatabase = DedicatedDatabase

@typing.final
class ServerlessDatabase(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    THROTTLING_RCU_LIMIT_FIELD_NUMBER: builtins.int
    STORAGE_SIZE_LIMIT_FIELD_NUMBER: builtins.int
    ENABLE_THROTTLING_RCU_LIMIT_FIELD_NUMBER: builtins.int
    PROVISIONED_RCU_LIMIT_FIELD_NUMBER: builtins.int
    TOPIC_WRITE_QUOTA_FIELD_NUMBER: builtins.int
    throttling_rcu_limit: builtins.int
    """Let's define 1 RU  - 1 request unit
    Let's define 1 RCU - 1 request capacity unit, which is 1 RU per second.
    If `enable_throttling_rcu_limit` flag is true, the database will be throttled using `throttling_rcu_limit` value.
    Otherwise, the database is throttled using the cloud quotas.
    If zero, all requests will be blocked until non zero value is set.
    """
    storage_size_limit: builtins.int
    """Specify serverless database storage size limit. If zero, default value is applied."""
    enable_throttling_rcu_limit: builtins.bool
    """If false, the database is throttled by cloud value."""
    provisioned_rcu_limit: builtins.int
    """Specify the number of provisioned RCUs to pay less if the database has predictable load.
    You will be charged for the provisioned capacity regularly even if this capacity is not fully consumed.
    You will be charged for the on-demand consumption only if provisioned capacity is consumed.
    """
    topic_write_quota: builtins.int
    """write quota for topic service, defined in bytes per second."""
    def __init__(
        self,
        *,
        throttling_rcu_limit: builtins.int = ...,
        storage_size_limit: builtins.int = ...,
        enable_throttling_rcu_limit: builtins.bool = ...,
        provisioned_rcu_limit: builtins.int = ...,
        topic_write_quota: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["enable_throttling_rcu_limit", b"enable_throttling_rcu_limit", "provisioned_rcu_limit", b"provisioned_rcu_limit", "storage_size_limit", b"storage_size_limit", "throttling_rcu_limit", b"throttling_rcu_limit", "topic_write_quota", b"topic_write_quota"]) -> None: ...

global___ServerlessDatabase = ServerlessDatabase

@typing.final
class ZonalDatabase(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ZONE_ID_FIELD_NUMBER: builtins.int
    zone_id: builtins.str
    def __init__(
        self,
        *,
        zone_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["zone_id", b"zone_id"]) -> None: ...

global___ZonalDatabase = ZonalDatabase

@typing.final
class RegionalDatabase(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REGION_ID_FIELD_NUMBER: builtins.int
    region_id: builtins.str
    def __init__(
        self,
        *,
        region_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["region_id", b"region_id"]) -> None: ...

global___RegionalDatabase = RegionalDatabase

@typing.final
class ScalePolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class FixedScale(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        SIZE_FIELD_NUMBER: builtins.int
        size: builtins.int
        def __init__(
            self,
            *,
            size: builtins.int = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["size", b"size"]) -> None: ...

    FIXED_SCALE_FIELD_NUMBER: builtins.int
    @property
    def fixed_scale(self) -> global___ScalePolicy.FixedScale: ...
    def __init__(
        self,
        *,
        fixed_scale: global___ScalePolicy.FixedScale | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["fixed_scale", b"fixed_scale", "scale_type", b"scale_type"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["fixed_scale", b"fixed_scale", "scale_type", b"scale_type"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["scale_type", b"scale_type"]) -> typing.Literal["fixed_scale"] | None: ...

global___ScalePolicy = ScalePolicy

@typing.final
class StorageConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STORAGE_OPTIONS_FIELD_NUMBER: builtins.int
    STORAGE_SIZE_LIMIT_FIELD_NUMBER: builtins.int
    storage_size_limit: builtins.int
    """output only field: storage size limit of dedicated database."""
    @property
    def storage_options(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___StorageOption]: ...
    def __init__(
        self,
        *,
        storage_options: collections.abc.Iterable[global___StorageOption] | None = ...,
        storage_size_limit: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["storage_options", b"storage_options", "storage_size_limit", b"storage_size_limit"]) -> None: ...

global___StorageConfig = StorageConfig

@typing.final
class StorageOption(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STORAGE_TYPE_ID_FIELD_NUMBER: builtins.int
    GROUP_COUNT_FIELD_NUMBER: builtins.int
    storage_type_id: builtins.str
    group_count: builtins.int
    def __init__(
        self,
        *,
        storage_type_id: builtins.str = ...,
        group_count: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["group_count", b"group_count", "storage_type_id", b"storage_type_id"]) -> None: ...

global___StorageOption = StorageOption
